searchData={"content_type":"text/markdown","items":[{"doc":"Top-level API for creating documents.","ref":"Mudbrick.html","title":"Mudbrick","type":"module"},{"doc":"Compression, OTF font with special characters and image placement:\n\n    iex> import Mudbrick.TestHelper                     # import some example fonts and images\n    ...> import Mudbrick\n    ...> alias Mudbrick.Page\n    ...> new(\n    ...>   compress: true,                              # flate compression for fonts, text etc.\n    ...>   fonts: %{bodoni: [file: bodoni_regular()]},  # register an OTF font\n    ...>   images: %{flower: [file: flower()]}          # register a JPEG\n    ...> )\n    ...> |> page(size: {100, 100})\n    ...> |> image(                                      # place preregistered JPEG\n    ...>   :flower,\n    ...>   scale: {100, 100},                           # full page size\n    ...>   position: {0, 0}                             # in points (1/72 inch), starts at bottom left\n    ...> )\n    ...> |> text(\n    ...>   {\"CO₂\", colour: {0, 0, 1}},                  # write blue text\n    ...>   font: :bodoni,                               # in the bodoni font\n    ...>   font_size: 14,                               # size 14 points\n    ...>   position: {35, 45}                           # 60 points from left, 45 from bottom of page\n    ...> )\n    ...> |> render()                                    # produce iodata, ready for File.write/2\n    ...> |> then(&File.write(\"examples/compression_font_special_chars.pdf\", &1))\n\nProduces this:","ref":"Mudbrick.html#module-example","title":"Example - Mudbrick","type":"module"},{"doc":"Compress data with the same method that PDF generation does. Useful for testing.","ref":"Mudbrick.html#compress/1","title":"Mudbrick.compress/1","type":"function"},{"doc":"iex> Mudbrick.compress([\"hi\", \"there\", [\"you\"]])\n    [<<120, 156, 203, 200, 44, 201, 72, 45, 74, 173, 204, 47, 5, 0, 23, 45, 4, 71>>]","ref":"Mudbrick.html#compress/1-example","title":"Example - Mudbrick.compress/1","type":"function"},{"doc":"Decompress data with the same method that PDF generation does. Useful for testing.","ref":"Mudbrick.html#decompress/1","title":"Mudbrick.decompress/1","type":"function"},{"doc":"iex> Mudbrick.decompress([<<120, 156, 203, 200, 44, 201, 72, 45, 74, 173, 204, 47, 5, 0, 23, 45, 4, 71>>])\n    [\"hithereyou\"]","ref":"Mudbrick.html#decompress/1-example","title":"Example - Mudbrick.decompress/1","type":"function"},{"doc":"Insert image previously registered in `new/1` at the given coordinates.","ref":"Mudbrick.html#image/3","title":"Mudbrick.image/3","type":"function"},{"doc":"- `:position` - `{x, y}` in points, relative to bottom-left corner.\n- `:scale` - `{w, h}` in points.\n- `:skew` - `{x, y}`, passed through to PDF `cm` operator.\n\nAll options default to `{0, 0}`.","ref":"Mudbrick.html#image/3-options","title":"Options - Mudbrick.image/3","type":"function"},{"doc":"iex> Mudbrick.new(images: %{lovely_flower: [file: Mudbrick.TestHelper.flower()]})\n    ...> |> Mudbrick.page()\n    ...> |> Mudbrick.image(:lovely_flower, position: {100, 100}, scale: {100, 100})\n\n    iex> Mudbrick.new()\n    ...> |> Mudbrick.page()\n    ...> |> Mudbrick.image(:my_face, position: {100, 100}, scale: {100, 100})\n    ** (Mudbrick.Image.Unregistered) Unregistered image: my_face\n\nTip: to make the image fit the page, pass e.g. `Page.size(:a4)` as the\n`scale` and `{0, 0}` as the `position`.","ref":"Mudbrick.html#image/3-examples","title":"Examples - Mudbrick.image/3","type":"function"},{"doc":"Start a new document.","ref":"Mudbrick.html#new/1","title":"Mudbrick.new/1","type":"function"},{"doc":"- `:compress` - when set to `true`, apply deflate compression to streams (if\n  compression saves space). Default: `false`\n- `:fonts` - register OTF or built-in fonts for later use.\n- `:images` - register images for later use.\n\nThe following options define metadata for the document:\n\n- `:producer` - software used to create the document, default: `\"Mudbrick\"`\n- `:creator_tool` - tool used to create the document, default: `\"Mudbrick\"`\n- `:create_date` - `DateTime` representing the document's creation time\n- `:modify_date` - `DateTime` representing the document's last update time\n- `:title` - title (can change e.g. browser window title), default: `nil`\n- `:creators` - list of names of the creators of the document, default: `[]`","ref":"Mudbrick.html#new/1-options","title":"Options - Mudbrick.new/1","type":"function"},{"doc":"Register an OTF font. Pass the file's raw data to the `:file` option.\n\n    iex> Mudbrick.new(fonts: %{bodoni: [file: Mudbrick.TestHelper.bodoni_regular()]})\n\nOr a built-in font. Note that these don't support right-alignment or special characters.\n\n    iex> Mudbrick.new(fonts: %{helvetica: [name: :Helvetica, type: :TrueType, encoding: :PDFDocEncoding]})\n\nRegister an image.\n\n    iex> Mudbrick.new(images: %{flower: [file: Mudbrick.TestHelper.flower()]})\n\nSet document metadata.\n\n    iex> Mudbrick.new(title: \"The best PDF\", producer: \"My cool software\")","ref":"Mudbrick.html#new/1-examples","title":"Examples - Mudbrick.new/1","type":"function"},{"doc":"Start a new page upon which future operators should apply.","ref":"Mudbrick.html#page/2","title":"Mudbrick.page/2","type":"function"},{"doc":"- `:size` - a tuple of `{width, height}`. Some standard sizes available in `Mudbrick.Page.size/1`.","ref":"Mudbrick.html#page/2-options","title":"Options - Mudbrick.page/2","type":"function"},{"doc":"Produce `iodata` from the current document.","ref":"Mudbrick.html#render/1","title":"Mudbrick.render/1","type":"function"},{"doc":"Write text at the given coordinates.","ref":"Mudbrick.html#text/3","title":"Mudbrick.text/3","type":"function"},{"doc":"- `:font` - *Required*. Name of a font previously registered with `new/1`.\n- `:position` - Coordinates from bottom-left of page in points. Default: `{0, 0}`.\n- `:font_size` - Size in points. Default: `12`.\n- `:leading` - Leading in points. Default is 120% of `:font_size`.\n- `:align` - Either `:left` or `:right`. Default: `:left`. Note that the rightmost point of right-aligned text is the horizontal offset provided to `:position`.","ref":"Mudbrick.html#text/3-top-level-options","title":"Top-level options - Mudbrick.text/3","type":"function"},{"doc":"When passing a `{text, opts}` tuple or list of tuples to this function, `opts` are:\n\n- `:colour` - `{r, g, b}` tuple. Each element is a number between 0 and 1. Default: `{0, 0, 0}`.\n- `:font` - Name of a font previously registered with `new/1`. Overrides the top-level option.\n- `:font_size` - Size in points. Overrides the top-level option.\n- `:leading` - The number of points to move down the page on the following linebreak. Overrides the top-level option.","ref":"Mudbrick.html#text/3-individual-write-options","title":"Individual write options - Mudbrick.text/3","type":"function"},{"doc":"Write \"CO₂\" in the bottom-left corner of a default-sized page.\n\n    iex> import Mudbrick.TestHelper\n    ...> import Mudbrick\n    ...> new(fonts: %{bodoni: [file: bodoni_regular()]})\n    ...> |> page()\n    ...> |> text(\"CO₂\", font: :bodoni)\n\nWrite \"I am red\" at 200, 200, where \"red\" is in red.\n\n    iex> import Mudbrick.TestHelper\n    ...> import Mudbrick\n    ...> new(fonts: %{bodoni: [file: bodoni_regular()]})\n    ...> |> page()\n    ...> |> text([\"I am \", {\"red\", colour: {1, 0, 0}}], font: :bodoni, position: {200, 200})\n\nWrite \"I am bold\" at 200, 200, where \"bold\" is in bold.\n\n    iex> import Mudbrick.TestHelper\n    ...> import Mudbrick\n    ...> new(fonts: %{regular: [file: bodoni_regular()], bold: [file: bodoni_bold()]})\n    ...> |> page()\n    ...> |> text([\"I am \", {\"bold\", font: :bold}], font: :regular, position: {200, 200})","ref":"Mudbrick.html#text/3-examples","title":"Examples - Mudbrick.text/3","type":"function"},{"doc":"","ref":"Mudbrick.html#t:coords/0","title":"Mudbrick.coords/0","type":"type"},{"doc":"","ref":"Mudbrick.Document.html","title":"Mudbrick.Document","type":"module"},{"doc":"","ref":"Mudbrick.Document.html#t:option/0","title":"Mudbrick.Document.option/0","type":"type"},{"doc":"","ref":"Mudbrick.Document.html#t:options/0","title":"Mudbrick.Document.options/0","type":"type"},{"doc":"","ref":"Mudbrick.Document.html#t:t/0","title":"Mudbrick.Document.t/0","type":"type"},{"doc":"","ref":"Mudbrick.Metadata.html","title":"Mudbrick.Metadata","type":"module"},{"doc":"","ref":"Mudbrick.Metadata.html#render/1","title":"Mudbrick.Metadata.render/1","type":"function"},{"doc":"","ref":"Mudbrick.Page.html","title":"Mudbrick.Page","type":"module"},{"doc":"Returns predefined page sizes in points.","ref":"Mudbrick.Page.html#size/1","title":"Mudbrick.Page.size/1","type":"function"},{"doc":"iex> Mudbrick.Page.size(:a4)\n    {597.6, 842.4}\n\n    iex> Mudbrick.Page.size(:a3)\n    {842.4, 1188.0}\n\n    iex> Mudbrick.Page.size(:letter)\n    {612.0, 792}","ref":"Mudbrick.Page.html#size/1-examples","title":"Examples - Mudbrick.Page.size/1","type":"function"},{"doc":"Useful for testing PDF documents.\n\nWhile these predicates do check the PDF in a black-box way, it's not expected\nthat they will work on all PDFs found in the wild.","ref":"Mudbrick.Predicates.html","title":"Mudbrick.Predicates","type":"module"},{"doc":"Checks for presence of `text` in the `pdf` `iodata`. Searches compressed and uncompressed data.\n\nThis arity only works with text that can be found in literal form inside a stream, compressed or uncompressed,","ref":"Mudbrick.Predicates.html#has_text?/2","title":"Mudbrick.Predicates.has_text?/2","type":"function"},{"doc":"Checks for presence of `text` in the `pdf` `iodata`. Searches compressed and uncompressed data.\n\nThis arity requires you to pass the raw font data in which the text is\nexpected to be written. It must be present in raw hexadecimal form\ncorresponding to the font's glyph IDs.\n\nThe [OpenType](https://hexdocs.pm/opentype) library is used to find font\nfeatures, such as ligatures, which are expected to have been used in the PDF.","ref":"Mudbrick.Predicates.html#has_text?/3","title":"Mudbrick.Predicates.has_text?/3","type":"function"},{"doc":"- `:in_font` - raw font data in which the text is expected.","ref":"Mudbrick.Predicates.html#has_text?/3-options","title":"Options - Mudbrick.Predicates.has_text?/3","type":"function"},{"doc":"iex> Mudbrick.Predicates.has_text?(\"some-pdf\", \"hello\", in_font: Mudbrick.TestHelper.bodoni_regular())","ref":"Mudbrick.Predicates.html#has_text?/3-example","title":"Example - Mudbrick.Predicates.has_text?/3","type":"function"},{"doc":"","ref":"Mudbrick.ContentStream.InvalidColour.html","title":"Mudbrick.ContentStream.InvalidColour","type":"exception"},{"doc":"","ref":"Mudbrick.Font.NotMeasured.html","title":"Mudbrick.Font.NotMeasured","type":"exception"},{"doc":"","ref":"Mudbrick.Font.Unregistered.html","title":"Mudbrick.Font.Unregistered","type":"exception"},{"doc":"","ref":"Mudbrick.Image.NotSupported.html","title":"Mudbrick.Image.NotSupported","type":"exception"},{"doc":"","ref":"Mudbrick.Image.Unregistered.html","title":"Mudbrick.Image.Unregistered","type":"exception"},{"doc":"# Mudbrick\n\n[API Documentation](https://hexdocs.pm/mudbrick/Mudbrick.html)\n\nEarly-stages PDF generator, beelining for:\n\n- PDF 2.0 support.\n- In-process, pure functional approach.\n- OpenType support.\n- Special characters and ligatures, like ₛᵤ₆ₛ꜀ᵣᵢₚₜₛ for chemical compounds etc.\n\nCurrently working:\n\n- OpenType fonts with ligatures and special characters.\n- Text positioning.\n- Right alignment.\n- Coloured text.\n- JPEG images.\n- Compression.\n\nTo do:\n\n- Other image formats.\n- Font subsetting.\n- Vector graphics.","ref":"readme.html","title":"Mudbrick","type":"extras"},{"doc":"```elixir\ndef deps do\n  [\n    {:mudbrick, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - Mudbrick","type":"extras"},{"doc":"- [elixir-pdf](https://github.com/andrewtimberlake/elixir-pdf), a more mature\n  library, supporting AFM instead of OTF fonts, but only the base\n  WinAnsiEncoding and no special characters. Uses a GenServer for state.\n- [erlguten](https://github.com/hwatkins/erlguten), an antiquated Erlang\n  PDF generator.\n- [opentype-elixir](https://github.com/jbowtie/opentype-elixir), used for OTF\n  parsing.\n- [ex_image_info](https://github.com/Group4Layers/ex_image_info), used for\n  image metadata parsing.","ref":"readme.html#see-also","title":"See also - Mudbrick","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}